#
# spec file for package wingpanel-indicator-sound
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.desktop.wingpanel.sound
Name:           wingpanel-indicator-sound
Version:        8.0.0
Release:        1.1
Summary:        Wingpanel Sound Indicator
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/wingpanel-indicator-sound
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(wingpanel)

%description
A sound indicator for Wingpanel.

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -Wno-error=return-type"
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}
%find_lang sound-indicator

%files
%license COPYING
%doc README.md
%dir %{_libdir}/wingpanel
%{_libdir}/wingpanel/libsound.so
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/io.elementary.wingpanel.sound.metainfo.xml

%files lang -f sound-indicator.lang

%changelog
* Wed Nov  6 2024 Richard Rahl <rrahl0@opensuse.org>
- fix CFLAGS
* Thu Aug 22 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Updated translations
- update to 7.0.0:
  * PlayerRow: use circle buttons
  * PlayerRow: keep label size consistent
  * volume-control: don't mute monitor sources
  * Resource: Update microphone icons
- update to 6.0.2:
  * Use device form factor when available to assign more accurate icons
  * Provide a fallback device icon when none is available
  * Fix missing switch animations
  * Use the volume step value from GNOME Settings Daemon
  * Updated translations
- update to 6.0.1:
  * fix HTML syntax (li tag outside ul tag)
  * Allow Horizontal scroll
  * MediaPlayer: Give type field valid name
  * DeviceItem: get icons from Pulse
- update to 6.0.0:
  * select specific input and output devices
  * Hide temporary audio players when they stop
  * Add a tooltip on hover
  * Minor visual improvements
  * Updated translations
- update to 2.1.8:
  * Fix duplicate default player
  * Updated translations
- update to 2.1.7:
  * Fix opacity flash during icon animation
  * Updated translations
- update to 2.1.6:
  * Update default music player when changed
  * Updated translations
- update to 2.1.5:
  * Correctly show "Unknown Artist" when artist info isn't available
  * Performance improvements
  * Updated translations
- switch url to github, so we don't link to a different OS
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.4:
  * Add AppData (#125)
  * Remove duplicate CI
  * Update POTFILES
  * Add Gettext Updates to Actions
  * Replace Granite.Services.Settings with GLib.Settings (#124)
  * run installation in CI (#121)
  * README: Fix weblate badge
  * use github workflows. add linting step in ci. (#117)
  * Test with GitHub CI (#120)
  * Delete CODE_OF_CONDUCT.md
  * indicator: lint file using vala-lint (#116)
  * :shirt: Lint widgets directory with vala-lint (#114)
  * :shirt: Lint services directory with vala-lint (#115)
  * build: fix install path for wingpanel indicator (#111)
  * Merge branch 'origin/master' into Weblate.
  * Scale: bind image icon_name to icon property (#97)
  * Tab → space
  * Disable markup support for title_label and artist_label and
    add Pango.Bold attribute to title_label
* Thu May  2 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.3:
  * Distinguish mouse and touchpad scroll events (#94)
  * DisplayWidget: Use mic icon allocated width instead of magic
    number (#96)
  * DisplayWidget: Animate mute icon (#95)
  * Fixed music player fallback icon logic (#91)
  * Only update art when url changed (#92)
  * Middle click mute microphone (#90)
  * Set disabled mic icon when appropriate (#79)
  * Fix smooth scrolling and horizontal scrolling (#81)
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.2:
  * Don't close an unexisting notification
  * Require wingpanel 2.1.0 (#76)
  * Update travis yml (#85)
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.1:
  * MprisGui: Remove unused Revealer and Box (#69)
  * Cleanup (#68)
  * MprisGui: Rewrite using Gtk.Grid (#67)
  * DisplayWidget: Bind widgets to properties (#66)
  * Add EditorConfig
  * Remove 'by' before artists (#65)
* Sat Jun 23 2018 avvissu@yandex.by
- Update to 2.1.0:
  * travis: add xmllint dependency
  * travis: add libcanberra-gtk3-dev dependency
  * RDNN (#63)
  * Remove unused gschema gettext domain
  * Link against libcanberra-gtk3 and not libcanberra-gtk (#57)
  * MPRISClient: Remove unused properties (#55)
  * MprisWidget: Handle GLib.Error with play_pause (#56)
  * Fix warnings about IOError (#54)
  * Remove CMake (#49)
  * Scale.vala: GObject-style (#53)
  * Click icon to mute and cleanup (#52)
  * Use Gtk.ModelButton (#47)
  * Install settings schema (#48)
  * Generate missing po files
  * Merge remote-tracking branch 'origin/master'
  * Meson: Add a var for gettext name (#44)
  * Add Meson build system (#43)
  * Don't add first separator if there are no media player
    controls (#37)
  * Remove unused try/catch (#32)
  * Add screenshot (#22)
  * Create .gitignore (#27)
  * Create CODE_OF_CONDUCT.md (#25)
  * Enable HiDPI on MPRIS images (#23)
  * Fix display widget being null (#21)
* Sat Jun  9 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Add pulseaudio as recommended
- Add README files
- Spec file cleanup
* Wed May  3 2017 avvissu@yandex.by
- Update to 2.0.5:
  * Center with respect to other widgets in the panel (#20)
  * Switch mic position to left, consistent with privacy
    indicator (#19)
* Sat Apr 22 2017 avvissu@yandex.by
- Update to 2.0.4:
  * use Settings URL scheme (#16)
  * Add Travis CI (#15)
  * Create README.md
  * Fix DBus binding of org.bluez.Adapter1 and org.bluez.Device1
  * Implements controls for paired bluetooth devices
  * Launchpad automatic translations update.
  * volume-control: Make property accessors match their base
  * Add Copying File
  * Re-license LGPL files to GPLv2
  * Create DisplayWidget.vala
  * If the microphone is in use, show a mic icon in the panel
  * Add image_mask to gresource
  * Create image_mask with gtk.overlay instead of cairo composite
  * Indicator.vala:
  * Fix whitespace
  * Don't use this
  * Don't have 3 different places where we define icons for
    volume levels
  * Make artists arrary unowned
  * Cache DBus variables in ClientWidget
  * Fix "g_str_hash" crash within DesktopAppInfo
* Tue Oct  4 2016 avvissu@yandex.by
- Update to 2.0.3
* Mon Sep 19 2016 avvissu@yandex.by
- Update to 2.0.1
- Add glib2_gsettings_schema_requires macro
- Change target_link_libraries
- Spec file cleanup
* Wed Oct 21 2015 and.november@opensuse.org
- initial package (version 0.1) for openSUSE
